@@ -1,41 +1,25 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: queue.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: queue.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.9  2000/07/10 01:31:17  bills
-oops - removed #define LIST_TRACE and #define QUEUE_DEBUG
-
-Revision 1.8  2000/07/10 01:26:56  bills
-added more trace messages, reworked packet delete handling: now happens
-during _icq_UDEQueueItemFree rather than during icq_UDPQueueDelSeq - fixes
-memory leak
-
-Revision 1.7  2000/07/09 22:07:37  bills
-use new list_free
-
-Revision 1.6  2000/06/25 16:30:05  denis
-Some sanity checks were added to icq_UDPQueueDelete() and
-icq_UDPQueueFree()
-
-Revision 1.5  2000/05/10 19:06:59  denis
-UDP outgoing packet queue was implemented.
-
-Revision 1.4  2000/03/30 14:15:28  denis
-Fixed FreeBSD warning about obsolete malloc.h header.
-
-Revision 1.3  2000/01/16 03:59:10  bills
-reworked list code so list_nodes don't need to be inside item structures,
-removed strlist code and replaced with generic list calls
-
-Revision 1.2  1999/09/29 17:06:47  denis
-ICQLINK compatibility added.
-
-Revision 1.1  1999/07/16 12:12:13  denis
-Initial support for outgoing packet queue added.
-
+*
+* $Id: queue.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 #include <stdlib.h>
@@ -55,7 +39,7 @@ void icq_UDPQueuePut(ICQLINK *link, icq_Packet *p, int attempt)
   icq_UDPQueueItem *ptr = (icq_UDPQueueItem*)malloc(sizeof(icq_UDPQueueItem));
 #ifdef QUEUE_DEBUG
   printf("icq_UDPQueuePut(seq=0x%04X, cmd=0x%04X)\n", icq_PacketReadUDPOutSeq1(p),
-         icq_PacketReadUDPOutCmd(p));
+	 icq_PacketReadUDPOutCmd(p));
 #endif
   ptr->attempts = attempt;
   ptr->expire = time(0L)+link->icq_UDPExpireInterval;
