@@ -1,56 +1,25 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: stdpackets.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: stdpackets.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.10  2000/06/15 01:51:23  bills
-added creation functions for cancel and refuse operations
-
-Revision 1.9  2000/05/04 15:50:38  bills
-warning cleanups
-
-Revision 1.8  2000/04/10 18:11:45  denis
-ANSI cleanups.
-
-Revision 1.7  2000/04/06 16:38:04  denis
-icq_*Send*Seq() functions with specified sequence number were added.
-
-Revision 1.6  2000/02/07 02:35:13  bills
-slightly modified chat packets
-
-Revision 1.5  2000/01/20 19:59:15  bills
-first implementation of sending file requests
-
-Revision 1.4  1999/09/29 20:12:32  bills
-tcp_link*->icq_TCPLink*
-
-Revision 1.3  1999/09/29 17:07:48  denis
-Host/network byteorder cleanups.
-
-Revision 1.2  1999/07/16 15:45:20  denis
-Cleaned up.
-
-Revision 1.1  1999/07/16 12:13:11  denis
-UDP packets support added.
-tcppackets.[ch] files renamed to stdpackets.[ch]
-
-Revision 1.9  1999/07/12 15:13:39  cproch
-- added definition of ICQLINK to hold session-specific global variabled
-  applications which have more than one connection are now possible
-- changed nearly every function defintion to support ICQLINK parameter
-
-Revision 1.8  1999/05/03 21:41:28  bills
-initial file xfer support added- untested
-
-Revision 1.7  1999/04/17 19:39:09  bills
-added new functions to create chat packets. removed unnecessary code.
-added new function to create URL ack packet.
-
-Revision 1.6  1999/04/14 15:08:39  denis
-Cleanups for "strict" compiling (-ansi -pedantic)
-
+*
+* $Id: stdpackets.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 #include <stdlib.h>
@@ -90,8 +59,8 @@ icq_Packet *icq_TCPCreateInitPacket(icq_TCPLink *plink)
 }
 
 icq_Packet *icq_TCPCreateStdPacket(icq_TCPLink *plink, WORD icq_TCPCommand,
-               WORD type, const unsigned char *msg, WORD status,
-               WORD msg_command)
+	       WORD type, const unsigned char *msg, WORD status,
+	       WORD msg_command)
 {
   icq_Packet *p=icq_PacketNew();
 
