@@ -1,60 +1,25 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: tcpfilehandle.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: tcpfilehandle.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.15  2000/07/24 03:10:08  bills
-added support for real nickname during TCP transactions like file and
-chat, instead of using Bill all the time (hmm, where'd I get that from? :)
-
-Revision 1.14  2000/07/09 22:19:35  bills
-added new *Close functions, use *Close functions instead of *Delete
-where correct, and misc cleanup
-
-Revision 1.13  2000/06/25 16:35:08  denis
-'\n' was added at the end of log messages.
-
-Revision 1.12  2000/06/15 01:52:59  bills
-fixed bug: sending file sessions would freeze if remote side changed speed
-
-Revision 1.11  2000/05/04 15:57:20  bills
-Reworked file transfer notification, small bugfixes, and cleanups.
-
-Revision 1.10  2000/05/03 18:29:15  denis
-Callbacks have been moved to the ICQLINK structure.
-
-Revision 1.9  2000/04/10 18:11:45  denis
-ANSI cleanups.
-
-Revision 1.8  2000/04/10 16:36:04  denis
-Some more Win32 compatibility from Guillaume Rosanis <grs@mail.com>
-
-Revision 1.7  2000/04/05 14:37:02  denis
-Applied patch from "Guillaume R." <grs@mail.com> for basic Win32
-compatibility.
-
-Revision 1.6  2000/01/20 20:06:00  bills
-removed debugging printfs
-
-Revision 1.5  2000/01/20 19:59:15  bills
-first implementation of sending file requests
-
-Revision 1.4  2000/01/16 21:29:31  bills
-added code so icq_FileSessions now keep track of the tcplink to which
-they are attached
-
-Revision 1.3  1999/12/21 00:30:15  bills
-added more file transfer logic to write file to disk
-
-Revision 1.2  1999/11/30 09:47:04  bills
-added icq_HandleFileHello
-
-Revision 1.1  1999/09/29 19:47:21  bills
-reworked chat/file handling.  fixed chat. (it's been broke since I put
-non-blocking connects in)
-
+*
+* $Id: tcpfilehandle.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 #include <time.h>
@@ -158,7 +123,7 @@ void icq_TCPProcessFilePacket(icq_Packet *p, icq_TCPLink *plink)
       /* respond */
       icq_FileSessionPrepareNextFile(psession);
       presponse=icq_TCPCreateFile02Packet(psession->current_file,
-        psession->current_file_size, psession->current_speed);
+	psession->current_file_size, psession->current_speed);
 
       icq_TCPLinkSend(plink, presponse);
 #ifdef TCP_PACKET_TRACE
@@ -169,7 +134,7 @@ void icq_TCPProcessFilePacket(icq_Packet *p, icq_TCPLink *plink)
     case 0x02:
       /* when files are skipped
       psession->total_transferred_bytes+=
-        (psession->current_file_size-psession->current_file_progress);
+	(psession->current_file_size-psession->current_file_progress);
       */
 
       (void)icq_PacketRead8(p);
@@ -186,7 +151,7 @@ void icq_TCPProcessFilePacket(icq_Packet *p, icq_TCPLink *plink)
 
       /* respond */
       presponse=icq_TCPCreateFile03Packet(psession->current_file_progress,
-         speed);
+	 speed);
 
       icq_TCPLinkSend(plink, presponse);
 #ifdef TCP_PACKET_TRACE
@@ -217,14 +182,14 @@ void icq_TCPProcessFilePacket(icq_Packet *p, icq_TCPLink *plink)
       speed=icq_PacketRead32(p);
       psession->current_speed=speed;
       if(plink->icqlink->icq_RequestNotify)
-        (*plink->icqlink->icq_RequestNotify)(plink->icqlink, plink->id,
-          ICQ_NOTIFY_FILE, FILE_STATUS_NEW_SPEED, 0);   
+	(*plink->icqlink->icq_RequestNotify)(plink->icqlink, plink->id,
+	  ICQ_NOTIFY_FILE, FILE_STATUS_NEW_SPEED, 0);   
       break;
 
     case 0x06:
       if(plink->icqlink->icq_RequestNotify)
-        (*plink->icqlink->icq_RequestNotify)(plink->icqlink, plink->id, ICQ_NOTIFY_FILEDATA,
-                           p->length-sizeof(BYTE), p->data+sizeof(BYTE));
+	(*plink->icqlink->icq_RequestNotify)(plink->icqlink, plink->id, ICQ_NOTIFY_FILEDATA,
+			   p->length-sizeof(BYTE), p->data+sizeof(BYTE));
       icq_FileSessionSetStatus(psession, FILE_STATUS_RECEIVING);
       result=write(psession->current_fd, p->data+sizeof(BYTE), p->length-sizeof(BYTE));
       psession->current_file_progress+=p->length-sizeof(BYTE);
