@@ -1,144 +1,26 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: tcplink.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: tcplink.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.38  2000/07/09 22:19:35  bills
-added new *Close functions, use *Close functions instead of *Delete
-where correct, and misc cleanup
-
-Revision 1.37  2000/06/15 01:53:17  bills
-added icq_TCPLinkSendSeq function
-
-Revision 1.36  2000/05/04 15:57:20  bills
-Reworked file transfer notification, small bugfixes, and cleanups.
-
-Revision 1.35  2000/05/03 18:29:15  denis
-Callbacks have been moved to the ICQLINK structure.
-
-Revision 1.34  2000/04/10 18:11:45  denis
-ANSI cleanups.
-
-Revision 1.33  2000/04/10 16:36:04  denis
-Some more Win32 compatibility from Guillaume Rosanis <grs@mail.com>
-
-Revision 1.32  2000/04/05 14:37:02  denis
-Applied patch from "Guillaume R." <grs@mail.com> for basic Win32
-compatibility.
-
-Revision 1.31  2000/02/15 04:00:16  bills
- new icq_ChatRusConv_n function
-
-Revision 1.30  2000/02/07 02:46:29  bills
-implemented non-blocking TCP connects over SOCKS, cyrillic translation for chat
-
-Revision 1.29  2000/01/20 19:59:35  bills
-fixed bug in icq_TCPLinkConnect that caused file/chat connection attempts
-to go to the wrong port
-
-Revision 1.28  2000/01/16 03:59:10  bills
-reworked list code so list_nodes don't need to be inside item structures,
-removed strlist code and replaced with generic list calls
-
-Revision 1.27  1999/12/27 16:13:29  bills
-fixed bug in icq_TCPOnDataReceived, removed flags variable ;)
-
-Revision 1.26  1999/12/27 10:56:10  denis
-Unused "flags" variable commented out.
-
-Revision 1.25  1999/12/21 00:30:53  bills
-added icq_TCPLinkProcessReceived to support processing receive queue
-before delete (packets used to get dropped in this instance, oops),
-reworked icq_TCPLinkOnDataReceived to handle quick, large streams of data,
-changed icq_TCPLinkOnConnect and *Accept to make all sockets non-blocking.
-
-Revision 1.24  1999/12/14 03:33:34  bills
-icq_TCPLinkConnect now uses real_ip when our IP is same as remote IP to make
-connection, added code to implement connect timeout
-
-Revision 1.23  1999/11/30 09:57:44  bills
-buffer overflow check added, tcplinks will now close if buffer overflows.
-increased icq_TCPLinkBufferSize to 4096 to support file transfer packets
-
-Revision 1.22  1999/11/29 17:15:51  denis
-Absence of socklen_t type fixed.
-
-Revision 1.21  1999/10/01 00:49:21  lord
-some compilation problems are fixed.
-
-Revision 1.20  1999/09/29 20:26:41  bills
-ack forgot the args :)
-
-Revision 1.19  1999/09/29 20:21:45  bills
-renamed denis' new function
-
-Revision 1.18  1999/09/29 20:11:29  bills
-renamed tcp_link* to icq_TCPLink*.  many cleanups, added icq_TCPLinkOnConnect
-
-Revision 1.17  1999/09/29 17:10:05  denis
-TCP code SOCKS-ification. Not finished.
-
-Revision 1.16  1999/07/18 20:21:34  bills
-fixed fail notification bug introduced during ICQLINK changes, changed to
-use new byte-order functions & contact list functions, added better log
-messages
-
-Revision 1.15  1999/07/16 15:45:57  denis
-Cleaned up.
-
-Revision 1.14  1999/07/16 12:02:58  denis
-tcp_packet* functions renamed to icq_Packet*
-Cleaned up.
-
-Revision 1.13  1999/07/12 15:13:36  cproch
-- added definition of ICQLINK to hold session-specific global variabled
-  applications which have more than one connection are now possible
-- changed nearly every function defintion to support ICQLINK parameter
-
-Revision 1.12  1999/07/03 06:33:51  lord
-. byte order conversion macros added
-. some compilation warnings removed
-
-Revision 1.11  1999/06/30 13:52:23  bills
-implemented non-blocking connects
-
-Revision 1.10  1999/05/03 21:39:41  bills
-removed exit calls
-
-Revision 1.9  1999/04/29 09:35:54  denis
-Cleanups, warning removed
-
-Revision 1.8  1999/04/17 19:34:49  bills
-fixed bug in icq_TCPLinkOnDataReceived, multiple packets that come in on
-one recv call are now handled correctly.  added icq_TCPLinkAccept and
-icq_TCPLinkListen.  started using mode and type structure entries.  added
-icq_TCPLinks list and icq_FindTCPLink function.  changed received_queue and
-send_queue to lists.
-
-Revision 1.7  1999/04/14 15:02:45  denis
-Cleanups for "strict" compiling (-ansi -pedantic)
-
-Revision 1.6  1999/04/05 18:47:17  bills
-initial chat support implemented
-
-Revision 1.5  1999/03/31 01:50:54  bills
-wrapped up many tcp details- tcp code now handles incoming and outgoing
-tcp messages and urls!
-
-Revision 1.4  1999/03/28 03:27:49  bills
-fixed icq_TCPLinkConnect so it really connects to remote ip instead of
-always my local test computer O:)
-
-Revision 1.3  1999/03/26 20:02:41  bills
-fixed C++ comments, cleaned up
-
-Revision 1.2  1999/03/25 22:21:59  bills
-added necessary includes
-
-Revision 1.1  1999/03/25 21:09:07  bills
-tcp link functions
+*
+* $Id: tcplink.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 #include <stdlib.h>
@@ -289,9 +171,9 @@ int icq_TCPLinkProxyConnect(icq_TCPLink *plink, DWORD uin, int port)
       host_struct = gethostbyname(plink->icqlink->icq_ProxyHost);
       if(host_struct == 0L)
       {
-        icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Can't find hostname: %s\n",
-                   plink->icqlink->icq_ProxyHost);
-        return -1;
+	icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Can't find hostname: %s\n",
+		   plink->icqlink->icq_ProxyHost);
+	return -1;
       }
       prsin.sin_addr = *((struct in_addr *)host_struct->h_addr);
     }
@@ -464,41 +346,41 @@ int icq_TCPLinkProxyConnectStatus(icq_TCPLink *plink)
     switch(buf[1])
     {
       case 1:
-        icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] General SOCKS server failure\n");
-        res = EFAULT;
-        break;
+	icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] General SOCKS server failure\n");
+	res = EFAULT;
+	break;
       case 2:
-        icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Connection not allowed by ruleset\n");
-        res = EACCES;
-        break;
+	icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Connection not allowed by ruleset\n");
+	res = EACCES;
+	break;
       case 3:
-        icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Network unreachable\n");
-        res = ENETUNREACH;
-        break;
+	icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Network unreachable\n");
+	res = ENETUNREACH;
+	break;
       case 4:
-        icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Host unreachable\n");
-        res = ENETUNREACH;
-        break;
+	icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Host unreachable\n");
+	res = ENETUNREACH;
+	break;
       case 5:
-        icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Connection refused\n");
-        res = ECONNREFUSED;
-        break;
+	icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Connection refused\n");
+	res = ECONNREFUSED;
+	break;
       case 6:
-        icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] TTL expired\n");
-        res = ETIMEDOUT;
-        break;
+	icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] TTL expired\n");
+	res = ETIMEDOUT;
+	break;
       case 7:
-        icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Command not supported\n");
-        res = EOPNOTSUPP;
-        break;
+	icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Command not supported\n");
+	res = EOPNOTSUPP;
+	break;
       case 8:
-        icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Address type not supported\n");
-        res = EAFNOSUPPORT;
-        break;
+	icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Address type not supported\n");
+	res = EAFNOSUPPORT;
+	break;
       default:
-        icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Unknown SOCKS server failure\n");
-        res = EFAULT;
-        break;
+	icq_FmtLog(plink->icqlink, ICQ_LOG_FATAL, "[SOCKS] Unknown SOCKS server failure\n");
+	res = EFAULT;
+	break;
     }
 #ifdef _WIN32
     closesocket(plink->socket);
@@ -617,15 +499,15 @@ icq_TCPLink *icq_TCPLinkAccept(icq_TCPLink *plink)
   
   if(pnewlink)
   {
-                socket=accept(plink->socket, (struct sockaddr *)&(plink->remote_address),
-                  &remote_length);
+		socket=accept(plink->socket, (struct sockaddr *)&(plink->remote_address),
+		  &remote_length);
 
-                icq_FmtLog(plink->icqlink, ICQ_LOG_MESSAGE,
-                        "accepting tcp connection from %s:%d\n",
-                        inet_ntoa(*((struct in_addr *)(&(plink->remote_address.sin_addr)))),
-                        ntohs(plink->remote_address.sin_port));
+		icq_FmtLog(plink->icqlink, ICQ_LOG_MESSAGE,
+			"accepting tcp connection from %s:%d\n",
+			inet_ntoa(*((struct in_addr *)(&(plink->remote_address.sin_addr)))),
+			ntohs(plink->remote_address.sin_port));
 
-                /* FIXME: make sure accept succeeded */
+		/* FIXME: make sure accept succeeded */
 
     pnewlink->type=plink->type;
     pnewlink->socket=socket;
@@ -674,10 +556,10 @@ int icq_TCPLinkListen(icq_TCPLink *plink)
     return -4;
 
   icq_FmtLog(plink->icqlink, ICQ_LOG_MESSAGE,
-             "created tcp listening socket %d, local address=%s:%d\n",
-             plink->socket,
-             inet_ntoa(*((struct in_addr *)(&plink->socket_address.sin_addr))),
-             ntohs(plink->socket_address.sin_port));
+	     "created tcp listening socket %d, local address=%s:%d\n",
+	     plink->socket,
+	     inet_ntoa(*((struct in_addr *)(&plink->socket_address.sin_addr))),
+	     ntohs(plink->socket_address.sin_port));
 
   plink->mode|=TCP_LINK_MODE_LISTEN;
   
@@ -694,24 +576,24 @@ void icq_ChatRusConv_n(const char to[4], char *t_in, int t_len)
     if((((unsigned char)t_in[i]) < ' ') && (t_in[i] != '\r'))
     {
       if(i - 1 > j)
-        icq_RusConv_n(to, &t_in[j], i - j - 1);
+	icq_RusConv_n(to, &t_in[j], i - j - 1);
       switch(t_in[i])
       {
-        case '\x07': /* Bell */
-        case '\x08': /* BackSpace */
-        case '\x03': /* Chat is active */
-        case '\x04': /* Chat is not active */
-             break;
-        case '\x00': /* Foregroung color (RR GG BB ?? ) */
-        case '\x01': /* Background color (RR GG BB ?? ) */
-        case '\x11': /* Font style change (Bold - 1, Italic - 2, Underline - 4) */
-        case '\x12': /* Font size change */
-             i += 4;
-             break;
-        case '\x10': /* Font family and encoding change */
-             i += t_in[i+1] + 2 + 2;
-             icq_RusConv_n(to, &t_in[i+3], t_in[i+1]);
-             break;
+	case '\x07': /* Bell */
+	case '\x08': /* BackSpace */
+	case '\x03': /* Chat is active */
+	case '\x04': /* Chat is not active */
+	     break;
+	case '\x00': /* Foregroung color (RR GG BB ?? ) */
+	case '\x01': /* Background color (RR GG BB ?? ) */
+	case '\x11': /* Font style change (Bold - 1, Italic - 2, Underline - 4) */
+	case '\x12': /* Font size change */
+	     i += 4;
+	     break;
+	case '\x10': /* Font family and encoding change */
+	     i += t_in[i+1] + 2 + 2;
+	     icq_RusConv_n(to, &t_in[i+3], t_in[i+1]);
+	     break;
       }
       j = i + 1;
     }
@@ -757,10 +639,10 @@ int icq_TCPLinkOnDataReceived(icq_TCPLink *plink)
     if(plink->mode & TCP_LINK_MODE_RAW) {
       /* notify the app with the new data */
       if(plink->type == TCP_LINK_CHAT)
-        icq_ChatRusConv_n("wk", plink->buffer, plink->buffer_count);
+	icq_ChatRusConv_n("wk", plink->buffer, plink->buffer_count);
       if(plink->icqlink->icq_RequestNotify)
-        (*plink->icqlink->icq_RequestNotify)(plink->icqlink, plink->id, ICQ_NOTIFY_CHATDATA,
-                           plink->buffer_count, plink->buffer);
+	(*plink->icqlink->icq_RequestNotify)(plink->icqlink, plink->id, ICQ_NOTIFY_CHATDATA,
+			   plink->buffer_count, plink->buffer);
       plink->buffer_count=0;
       continue;
     }
@@ -774,32 +656,32 @@ int icq_TCPLinkOnDataReceived(icq_TCPLink *plink)
       /* warn if the buffer is too small to hold the whole packet */
       if(packet_size>icq_TCPLinkBufferSize-sizeof(WORD))
       {
-        icq_FmtLog(plink->icqlink, ICQ_LOG_WARNING, "tcplink buffer "
-          "overflow, packet size = %d, buffer size = %d, closing link\n",
-          packet_size, icq_TCPLinkBufferSize);
+	icq_FmtLog(plink->icqlink, ICQ_LOG_WARNING, "tcplink buffer "
+	  "overflow, packet size = %d, buffer size = %d, closing link\n",
+	  packet_size, icq_TCPLinkBufferSize);
 //        icq_TCPLinkClose(plink);
-        return 0;
+	return 0;
       }
 
       if(packet_size+sizeof(WORD) <= (unsigned)plink->buffer_count)
       {
-        /* copy the packet into memory */
-        icq_Packet *p=icq_PacketNew();
-        icq_PacketAppend(p, buffer+sizeof(WORD), packet_size);
+	/* copy the packet into memory */
+	icq_Packet *p=icq_PacketNew();
+	icq_PacketAppend(p, buffer+sizeof(WORD), packet_size);
 
-        /* remove it from the buffer */
-        memcpy(buffer, buffer+packet_size+sizeof(WORD),
-             plink->buffer_count-packet_size-sizeof(WORD));
+	/* remove it from the buffer */
+	memcpy(buffer, buffer+packet_size+sizeof(WORD),
+	     plink->buffer_count-packet_size-sizeof(WORD));
 
-        plink->buffer_count-=(packet_size+sizeof(WORD));
+	plink->buffer_count-=(packet_size+sizeof(WORD));
 
-        icq_TCPLinkOnPacketReceived(plink, p);
+	icq_TCPLinkOnPacketReceived(plink, p);
       }
       else
       {
-        /* not enough bytes in buffer to form the complete packet.
-         * we're done for now */
-        done=1;
+	/* not enough bytes in buffer to form the complete packet.
+	 * we're done for now */
+	done=1;
       }
     } /* while packets remain in buffer */
 
@@ -846,8 +728,8 @@ void icq_TCPLinkOnConnect(icq_TCPLink *plink)
   getsockopt(plink->socket, SOL_SOCKET, SO_ERROR, &error, &len);
 #endif
   if(!error && (plink->mode & (TCP_LINK_SOCKS_CONNECTING | TCP_LINK_SOCKS_AUTHORIZATION |
-                               TCP_LINK_SOCKS_AUTHSTATUS | TCP_LINK_SOCKS_NOAUTHSTATUS |
-                               TCP_LINK_SOCKS_CROSSCONNECT | TCP_LINK_SOCKS_CONNSTATUS)))
+			       TCP_LINK_SOCKS_AUTHSTATUS | TCP_LINK_SOCKS_NOAUTHSTATUS |
+			       TCP_LINK_SOCKS_CROSSCONNECT | TCP_LINK_SOCKS_CONNSTATUS)))
   {
     if(plink->mode & TCP_LINK_SOCKS_CONNECTING)
        error = icq_TCPLinkProxyRequestAuthorization(plink);
@@ -883,12 +765,12 @@ void icq_TCPLinkOnConnect(icq_TCPLink *plink)
   getsockname(plink->socket, (struct sockaddr *)&plink->socket_address, &len);
 
   icq_FmtLog(plink->icqlink, ICQ_LOG_MESSAGE,
-             "connected to uin %d, socket=%d local address=%s:%d remote address=%s:%d\n",
-             plink->remote_uin, plink->socket,
-             inet_ntoa(*((struct in_addr *)(&plink->socket_address.sin_addr))),
-             ntohs(plink->socket_address.sin_port),
-             inet_ntoa(*((struct in_addr *)(&plink->remote_address.sin_addr))),
-             ntohs(plink->remote_address.sin_port));
+	     "connected to uin %d, socket=%d local address=%s:%d remote address=%s:%d\n",
+	     plink->remote_uin, plink->socket,
+	     inet_ntoa(*((struct in_addr *)(&plink->socket_address.sin_addr))),
+	     ntohs(plink->socket_address.sin_port),
+	     inet_ntoa(*((struct in_addr *)(&plink->remote_address.sin_addr))),
+	     ntohs(plink->remote_address.sin_port));
 
   plink->mode&= ~TCP_LINK_MODE_CONNECTING;
 
@@ -899,7 +781,7 @@ void icq_TCPLinkOnConnect(icq_TCPLink *plink)
     icq_Packet *p=list_dequeue(plink->send_queue);
     if(p->id)
       if(plink->icqlink->icq_RequestNotify)
-        (*plink->icqlink->icq_RequestNotify)(plink->icqlink, p->id, ICQ_NOTIFY_CONNECTED, 0, 0);
+	(*plink->icqlink->icq_RequestNotify)(plink->icqlink, p->id, ICQ_NOTIFY_CONNECTED, 0, 0);
     icq_TCPLinkSend(plink, p);
   }
 
@@ -940,7 +822,7 @@ unsigned long icq_TCPLinkSendSeq(icq_TCPLink *plink, icq_Packet *p,
     icq_PacketSend(p, plink->socket);
     if(p->id)
       if(plink->icqlink->icq_RequestNotify)
-        (*plink->icqlink->icq_RequestNotify)(plink->icqlink, p->id, ICQ_NOTIFY_SENT, 0, 0);
+	(*plink->icqlink->icq_RequestNotify)(plink->icqlink, p->id, ICQ_NOTIFY_SENT, 0, 0);
     icq_PacketDelete(p);
   }
   return sequence;
@@ -958,7 +840,7 @@ void icq_TCPLinkSend(icq_TCPLink *plink, icq_Packet *p)
     icq_PacketSend(p, plink->socket);
     if(p->id)
       if(plink->icqlink->icq_RequestNotify)
-        (*plink->icqlink->icq_RequestNotify)(plink->icqlink, p->id, ICQ_NOTIFY_SENT, 0, 0);
+	(*plink->icqlink->icq_RequestNotify)(plink->icqlink, p->id, ICQ_NOTIFY_SENT, 0, 0);
     icq_PacketDelete(p);
   }
 }
@@ -980,17 +862,17 @@ void icq_TCPLinkProcessReceived(icq_TCPLink *plink)
 
       switch (plink->type) {
 
-        case TCP_LINK_MESSAGE:
-          icq_TCPProcessPacket(p, plink);
-          break;
+	case TCP_LINK_MESSAGE:
+	  icq_TCPProcessPacket(p, plink);
+	  break;
 
-        case TCP_LINK_CHAT:
-          icq_TCPProcessChatPacket(p, plink);
-          break;
+	case TCP_LINK_CHAT:
+	  icq_TCPProcessChatPacket(p, plink);
+	  break;
 
-        case TCP_LINK_FILE:
-          icq_TCPProcessFilePacket(p, plink);
-          break;
+	case TCP_LINK_FILE:
+	  icq_TCPProcessFilePacket(p, plink);
+	  break;
 
       }
     }
