@@ -59,6 +59,16 @@ static const BYTE icq_UDPTable[] = {
   0x47, 0x43, 0x69, 0x48, 0x33, 0x51, 0x54, 0x5D, 0x6E, 0x3C, 0x31, 0x64, 0x35, 0x5A, 0x00, 0x00,
 };
 
+const char *rus(const char *s) {
+    static char rbuf[512];
+
+    strcpy(rbuf, s);
+    rbuf[512] = 0;
+    icq_RusConv("kw", rbuf);
+
+    return rbuf;
+}
+
 void icq_UDPCheckCode(icq_Packet *p)
 {
   DWORD num1, num2;
@@ -454,16 +464,11 @@ message to send.
 ***************************************************/
 WORD icq_UDPSendMessage(ICQLINK *link, DWORD uin, const char *text) /* V5 */
 {
-  char buf[512]; /* message may be only 450 bytes long */
-  icq_Packet *p;
+  icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_SEND_THRU_SRV);
 
-  strncpy(buf, text, 512);
-  icq_RusConv("kw", buf);
-
-  p = icq_UDPCreateStdPacket(link, UDP_CMD_SEND_THRU_SRV);
   icq_PacketAppend32(p, uin);
   icq_PacketAppend16(p, TYPE_MSG);
-  icq_PacketAppendString(p, buf);
+  icq_PacketAppendString(p, rus(text));
 
   icq_UDPSockWrite(link, p);
   icq_PacketDelete(p);
@@ -588,25 +593,12 @@ void icq_SendSearchReq(ICQLINK *link, const char *email, const char *nick, const
 		       const char *last) /* V5 */
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_SEARCH_USER);
-  char nnick[512];
-  char nfirst[512];
-  char nlast[512];
-  char nemail[512];
 
-  strcpy(nnick, nick);
-  strcpy(nfirst, first);
-  strcpy(nlast, last);
-  strcpy(nemail, email);
+  icq_PacketAppendString(p, rus(nick));
+  icq_PacketAppendString(p, rus(first));
+  icq_PacketAppendString(p, rus(last));
+  icq_PacketAppendString(p, rus(email));
 
-  icq_RusConv("kw", nnick);
-  icq_RusConv("kw", nfirst);
-  icq_RusConv("kw", nlast);
-  icq_RusConv("kw", nemail);
-
-  icq_PacketAppendString(p, nnick);
-  icq_PacketAppendString(p, nfirst);
-  icq_PacketAppendString(p, nlast);
-  icq_PacketAppendString(p, nemail);
   icq_UDPSockWrite(link, p);
   icq_PacketDelete(p);
 }
@@ -647,10 +639,11 @@ WORD icq_UpdateUserInfo(ICQLINK *link, const char *nick, const char *first, cons
 			const char *email) /* V5 */
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_UPDATE_INFO);
-  icq_PacketAppendString(p, nick);
-  icq_PacketAppendString(p, first);
-  icq_PacketAppendString(p, last);
-  icq_PacketAppendString(p, email);
+
+  icq_PacketAppendString(p, rus(nick));
+  icq_PacketAppendString(p, rus(first));
+  icq_PacketAppendString(p, rus(last));
+  icq_PacketAppendString(p, rus(email));
 /* auth (byte)? */
   icq_UDPSockWrite(link, p);
   icq_PacketDelete(p);
@@ -673,19 +666,21 @@ WORD icq_UpdateMetaInfoSet(ICQLINK *link, const char *nick, const char *first, c
 			   unsigned short cnt_code, unsigned char cnt_stat, unsigned char emailhide)
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_META_USER);
+
   icq_PacketAppend16(p, META_CMD_SET_INFO);
-  icq_PacketAppendString(p, nick);
-  icq_PacketAppendString(p, first);
-  icq_PacketAppendString(p, last);
-  icq_PacketAppendString(p, email);
-  icq_PacketAppendString(p, email2);
-  icq_PacketAppendString(p, email3);
-  icq_PacketAppendString(p, city);
-  icq_PacketAppendString(p, state);
-  icq_PacketAppendString(p, phone);
-  icq_PacketAppendString(p, fax);
-  icq_PacketAppendString(p, street);
-  icq_PacketAppendString(p, cellular);
+
+  icq_PacketAppendString(p, rus(nick));
+  icq_PacketAppendString(p, rus(first));
+  icq_PacketAppendString(p, rus(last));
+  icq_PacketAppendString(p, rus(email));
+  icq_PacketAppendString(p, rus(email2));
+  icq_PacketAppendString(p, rus(email3));
+  icq_PacketAppendString(p, rus(city));
+  icq_PacketAppendString(p, rus(state));
+  icq_PacketAppendString(p, rus(phone));
+  icq_PacketAppendString(p, rus(fax));
+  icq_PacketAppendString(p, rus(street));
+  icq_PacketAppendString(p, rus(cellular));
   icq_PacketAppend32(p, zip);
   icq_PacketAppend16(p, cnt_code);
   icq_PacketAppend8(p, cnt_stat);
@@ -708,7 +703,7 @@ WORD icq_UpdateMetaInfoHomepage(ICQLINK *link, unsigned char age, const char *ho
 /*
   icq_PacketAppend16(p, 0x0200);
 */
-  icq_PacketAppendString(p, homepage);
+  icq_PacketAppendString(p, rus(homepage));
   icq_PacketAppend8(p, year);
   icq_PacketAppend8(p, month);
   icq_PacketAppend8(p, day);
@@ -724,7 +719,7 @@ WORD icq_UpdateMetaInfoAbout(ICQLINK *link, const char *about)
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_META_USER);
   icq_PacketAppend16(p, META_CMD_SET_ABOUT);
-  icq_PacketAppendString(p, about);
+  icq_PacketAppendString(p, rus(about));
   icq_UDPSockWrite(link, p);
   icq_PacketDelete(p);
   return link->icq_UDPSeqNum2-1;
@@ -747,15 +742,17 @@ WORD icq_UpdateNewUserInfo(ICQLINK *link, const char *nick, const char *first, c
 			   const char *email) /* V5 */
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_NEW_USER_INFO);
-  icq_PacketAppendString(p, nick);
-  icq_PacketAppendString(p, first);
-  icq_PacketAppendString(p, last);
-  icq_PacketAppendString(p, email);
+
+  icq_PacketAppendString(p, rus(nick));
+  icq_PacketAppendString(p, rus(first));
+  icq_PacketAppendString(p, rus(last));
+  icq_PacketAppendString(p, rus(email));
   icq_PacketAppend8(p, 1);
   icq_PacketAppend8(p, 1);
   icq_PacketAppend8(p, 1);
   icq_UDPSockWrite(link, p);
   icq_PacketDelete(p);
+
   return link->icq_UDPSeqNum1-1;
 }
 
