@@ -1,111 +1,26 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: udphandle.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: udphandle.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.28  2000/06/25 17:25:52  denis
-icq_HandleMetaUserInfo() handles all (!) available in original icq2k
-Meta User Info packets along with other useful Meta* packets. (WOW! ;)
-
-Revision 1.27  2000/05/10 18:54:43  denis
-icq_Disconnect() now called before icq_Disconnected callback to
-prevent high CPU usage in kicq's "reconnect on disconnect" code.
-
-Revision 1.26  2000/05/03 18:29:15  denis
-Callbacks have been moved to the ICQLINK structure.
-
-Revision 1.25  2000/02/07 02:48:15  bills
-changed log message in HandleUserOnline
-
-Revision 1.24  2000/01/16 03:59:10  bills
-reworked list code so list_nodes don't need to be inside item structures,
-removed strlist code and replaced with generic list calls
-
-Revision 1.23  1999/12/27 11:12:37  denis
-icq_UpdateMetaInfoSecurity() added for setting "My authorization is
-required", "Web Aware" and "IP Publishing".
-
-Revision 1.22  1999/12/14 03:37:06  bills
-removed old real_ip->ip masq hack, added store to remote_real_ip in
-icq_ContactItem
-
-Revision 1.21  1999/12/12 18:03:58  denis
-Authorization Request packet handling fixed.
-
-Revision 1.20  1999/11/29 17:18:31  denis
-icq_DoMsg() redone using string lists.
-
-Revision 1.18  1999/11/11 15:10:32  guruz
-- Added Base for Webpager Messages. Please type "make fixme"
-- Removed Segfault when kicq is started the first time
-
-Revision 1.17  1999/10/14 11:44:04  denis
-Cleanups.
-
-Revision 1.16  1999/09/29 17:16:08  denis
-MailExpress message handler started.
-
-Revision 1.15  1999/07/18 20:23:54  bills
-fixed tcp port bug in icq_HandleUserOnline, changed to use new byte-order
-& contact list functions
-
-Revision 1.14  1999/07/16 15:46:02  denis
-Cleaned up.
-
-Revision 1.13  1999/07/16 12:40:55  denis
-ICQ UDP v5 implemented.
-Encription for ICQ UDP v5 implemented.
-icq_Packet* unified interface for UDP packets implemented.
-Multipacket support of ICQ UDP v5 support added.
-
-Revision 1.12  1999/07/12 15:13:45  cproch
-- added definition of ICQLINK to hold session-specific global variabled
-  applications which have more than one connection are now possible
-- changed nearly every function defintion to support ICQLINK parameter
-
-Revision 1.11  1999/07/03 06:46:54  lord
-converting icq_userOnline callback parameters to correct
-byte order.
-
-Revision 1.10  1999/07/03 02:29:46  bills
-added code to HandleUserOnline to update tcp_flag
-
-Revision 1.9  1999/04/29 09:40:54  denis
-Unsuccessful attempt to implement web presence (webaware) feature
-
-Revision 1.8  1999/04/18 01:58:37  bills
-changed icq_SrvAck call to icq_RequestNotify
-
-Revision 1.7  1999/04/17 19:26:49  bills
-removed *_link entries from icq_ContactItem, including cleaup/init code
-
-Revision 1.6  1999/04/14 15:05:39  denis
-Cleanups for "strict" compiling (-ansi -pedantic)
-Switched from icq_Log callback to icq_Fmt function.
-
-Revision 1.5  1999/04/05 18:47:23  bills
-initial chat support implemented
-
-Revision 1.4  1999/03/31 01:39:50  bills
-added handling of tcp_flag in HandleLogin
-
-Revision 1.3  1999/03/28 03:35:17  bills
-fixed function names so icqlib compiles, fixed bug in HandleUserOnline
-(remote_ip and remote_real_ip were not evaluating correctly), added
-hack so I can test using local network
-
-Revision 1.2  1999/03/25 22:25:02  bills
-modified icq_HandleUserOnline & Offline for new message_link
-
-Revision 1.1  1999/03/24 11:37:38  denis
-Underscored files with TCP stuff renamed.
-TCP stuff cleaned up
-Function names changed to corresponding names.
-icqlib.c splitted to many small files by subject.
-C++ comments changed to ANSI C comments.
-
+*
+* $Id: udphandle.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 #include <stdlib.h>
