@@ -73,8 +73,8 @@ texteditor::~texteditor() {
     delete files;
 }
 
-int texteditor::load(string buf, char *id) {
-    int newfn = addwindow(id), k;
+int texteditor::load(string buf, const string id) {
+    int newfn = addwindow(strdup(id.c_str())), k;
     vector<string> lst;
     vector<string>::iterator i;
 
@@ -91,7 +91,7 @@ int texteditor::load(string buf, char *id) {
     return newfn;
 }
 
-int texteditor::load(FILE *f, char *id) {
+int texteditor::load(FILE *f, const string id) {
     int i = -1;
     struct stat st;
     char *p = 0;
@@ -102,7 +102,7 @@ int texteditor::load(FILE *f, char *id) {
 	fseek(f, 0, SEEK_SET);
 	fread(p, st.st_size, 1, f);
 	p[st.st_size] = 0;
-	i = load(p, id);
+	i = load(p, strdup(id.c_str()));
 	delete p;
     }
 
@@ -163,7 +163,6 @@ char *texteditor::save(const char *linebreak) {
 	    strcat(buf, p);
     }
 
-    modified = false;
     return buf;
 }
 
@@ -171,6 +170,7 @@ int texteditor::save(FILE *f, const char *linebreak) {
     char *buf = save(linebreak);
     fwrite(buf, strlen(buf), 1, f);
     delete buf;
+    modified = false;
     return 0;
 }
 
@@ -178,6 +178,7 @@ int texteditor::save(ofstream &f, const string linebreak) {
     char *buf = save(linebreak.c_str());
     f.write(buf, strlen(buf));
     f.close();
+    modified = false;
     return 0;
 }
 
@@ -354,18 +355,24 @@ void texteditor::addblock(int x1, int y1, int x2, int y2, int color) {
 
 void texteditor::startmark() {
     CHECKLOADED;
-    curfile->markmode = curfile->showmarked = true;
-    curfile->markreverse = false;
-    curfile->markblock->x1 = curfile->markblock->x2 = CURCOL;
-    curfile->markblock->y1 = curfile->markblock->y2 = CURLINE;
-    curfile->markblock->color = colors.blockcolor;
-    draw();
+
+    if(!curfile->markmode) {
+	curfile->markmode = curfile->showmarked = true;
+	curfile->markreverse = false;
+	curfile->markblock->x1 = curfile->markblock->x2 = CURCOL;
+	curfile->markblock->y1 = curfile->markblock->y2 = CURLINE;
+	curfile->markblock->color = colors.blockcolor;
+	draw();
+    }
 }
 
 void texteditor::endmark() {
     CHECKLOADED;
-    marktext();
-    curfile->markmode = false;
+
+    if(curfile->markmode) {
+	marktext();
+	curfile->markmode = false;
+    }
 }
 
 void texteditor::marktext() {
@@ -682,7 +689,8 @@ void texteditor::hl_comment(char *cp, char *txt, int color) {
 
 void texteditor::hl_comment(char *cp, int st, int pend, int color) {
     int i, delcount = 0;
-    char ins[5] = "\001 ", origclr = -1;
+    char ins[5] = "\001 ";
+    int origclr = -1;
 
     if(color) {
 	for(i = 0; (i <= pend) && (i < strlen(cp)); i++)
